#!/usr/bin/env python
# encoding: utf-8
"""
delegate/__version__.py

Created by Alexander Bohn on 2011-02-08.
Copyright (c) 2011 Objects in Space and Time. All rights reserved.

"""
__author__ = 'Alexander Bohn'
__email__ = 'fish2000@gmail.com'
__version__ = (0, 2, 7)
__doc__ = '''
Automatic delegate methods for Django managers and querysets,
without runtime dispatch penalties.
'''